==> react-lds-8.7.0.tgz: package/es/components/GroupedCombobox/GroupedComboboxContainer.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.object.set-prototype-of";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { itemType } from '../Combobox/utils/constants';
import { BaseCombobox } from '../Combobox';

var GroupedComboboxContainer =
/*#__PURE__*/
function (_Component) {
  _inherits(GroupedComboboxContainer, _Component);

  function GroupedComboboxContainer() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, GroupedComboboxContainer);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(GroupedComboboxContainer)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "onSelect", function (id) {
      var onSelect = _this.props.onSelect;
      onSelect(id);
    });

    _defineProperty(_assertThisInitialized(_this), "renderSwitcher", function () {
      var _this$props = _this.props,
          id = _this$props.id,
          isOpen = _this$props.isOpen,
          items = _this$props.items,
          onToggle = _this$props.onToggle,
          selectedItems = _this$props.selectedItems;
      return React.createElement(BaseCombobox, {
        closeOnSelect: true,
        hideLabel: true,
        id: id,
        isMultiSelect: false,
        isOpen: isOpen,
        items: items,
        label: "",
        onSelect: _this.onSelect,
        onToggle: onToggle,
        placeholder: "",
        selectedItems: selectedItems
      });
    });

    return _this;
  }

  _createClass(GroupedComboboxContainer, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          items = _this$props2.items,
          selectedItems = _this$props2.selectedItems;
      if (!selectedItems.length) return null;

      var _selectedItems = _slicedToArray(selectedItems, 1),
          activeId = _selectedItems[0].id;

      return children({
        activeId: activeId,
        items: items,
        comboboxProps: {
          isMultiSelect: true,
          renderObjectSwitcher: this.renderSwitcher
        }
      });
    }
  }]);

  return GroupedComboboxContainer;
}(Component);

GroupedComboboxContainer.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.func.isRequired,
  id: PropTypes.string.isRequired,
  isOpen: PropTypes.bool.isRequired,
  items: PropTypes.arrayOf(itemType).isRequired,
  onSelect: PropTypes.func.isRequired,
  onToggle: PropTypes.func.isRequired,
  selectedItems: PropTypes.arrayOf(itemType).isRequired
} : {};
export default GroupedComboboxContainer;

==> react-lds-9.1.0.tgz: package/es/components/GroupedCombobox/GroupedComboboxContainer.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { itemType } from '../Combobox/utils/constants';
import { BaseCombobox } from '../Combobox';

var GroupedComboboxContainer =
/*#__PURE__*/
function (_Component) {
  _inherits(GroupedComboboxContainer, _Component);

  function GroupedComboboxContainer() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, GroupedComboboxContainer);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(GroupedComboboxContainer)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "onSelect", function (id) {
      var onSelect = _this.props.onSelect;
      onSelect(id);
    });

    _defineProperty(_assertThisInitialized(_this), "renderSwitcher", function () {
      var _this$props = _this.props,
          id = _this$props.id,
          isOpen = _this$props.isOpen,
          items = _this$props.items,
          onToggle = _this$props.onToggle,
          selectedItems = _this$props.selectedItems;
      return React.createElement(BaseCombobox, {
        closeOnSelect: true,
        hideLabel: true,
        id: id,
        isMultiSelect: false,
        isOpen: isOpen,
        items: items,
        label: "",
        onSelect: _this.onSelect,
        onToggle: onToggle,
        placeholder: "",
        selectedItems: selectedItems
      });
    });

    return _this;
  }

  _createClass(GroupedComboboxContainer, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          items = _this$props2.items,
          selectedItems = _this$props2.selectedItems;
      if (!selectedItems.length) return null;

      var _selectedItems = _slicedToArray(selectedItems, 1),
          activeId = _selectedItems[0].id;

      return children({
        activeId: activeId,
        items: items,
        comboboxProps: {
          isMultiSelect: true,
          renderObjectSwitcher: this.renderSwitcher
        }
      });
    }
  }]);

  return GroupedComboboxContainer;
}(Component);

GroupedComboboxContainer.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.func.isRequired,
  id: PropTypes.string.isRequired,
  isOpen: PropTypes.bool.isRequired,
  items: PropTypes.arrayOf(itemType).isRequired,
  onSelect: PropTypes.func.isRequired,
  onToggle: PropTypes.func.isRequired,
  selectedItems: PropTypes.arrayOf(itemType).isRequired
} : {};
export default GroupedComboboxContainer;
